(*  GREATIS RUNTIME FUSION                    *)
(*  unit version 010                          *)
(*  Copyright (C) 2001-2013 Greatis Software  *)
(*  http://www.greatis.com/delphicb/runtime/  *)
(*  http://www.greatis.com/bteam.html         *)

unit RunFus;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  FDMain, CompInsp;

type

  TRFInspector = class;

  TRFTree = class(TComponentTree)
  private
    { Private declarations }
    FShowContainers: Boolean;
    procedure SetShowContainers(const Value: Boolean);
  protected
    { Protected declarations }
    function Filter(AComponent: TComponent): Boolean; override;
  published
    { Published declarations }
    property ShowContainers: Boolean read FShowContainers write SetShowContainers;
  end;

  TRFComboBox = class(TComponentComboBox)
  protected
    { Protected declarations }
    function TranslateComponent(AComponent: TComponent): TComponent; override;
  {$IFDEF HHADD}
  published
    property Align;
  {$ENDIF}
  end;

  TRFDesigner = class(TFormDesigner)
  private
    { Private declarations }
    FInspector: TRFInspector;
    FLockFusionDesigner: Boolean;
    procedure SetInspector(const Value: TRFInspector);
  protected
    { Protected declarations }
    procedure Notification(AComponent: TComponent; Operation: TOperation); override;
    procedure DoChange; override;
    procedure DoSelectionChange; override;
  published
    { Published declarations }
    property Inspector: TRFInspector read FInspector write SetInspector;
  end;

  TRFInspector = class(TComponentInspector)
  private
    { Private declarations }
    FDesigner: TRFDesigner;
    FDefaultInstance: TComponent;
    procedure SetDesigner(const Value: TRFDesigner);
    procedure SetDefaultInstance(const Value: TComponent);
  protected
    { Protected declarations }
    procedure Notification(AComponent: TComponent; Operation: TOperation); override;
    procedure Change(TheIndex: Integer); override;
  published
    { Published declarations }
    property Designer: TRFDesigner read FDesigner write SetDesigner;
    property DefaultInstance: TComponent read FDefaultInstance write SetDefaultInstance;
  public
    { Public declarations }
    procedure Update; override;
  end;

implementation

procedure TRFTree.SetShowContainers(const Value: Boolean);
begin
  if FShowContainers<>Value then
  begin
    FShowContainers:=Value;
    if not (csDesigning in ComponentState) then RefreshTree;
  end;
end;

function TRFTree.Filter(AComponent: TComponent): Boolean;
begin
  Result:=(AComponent<>Self) and
    (ShowNonVisual or (AComponent is TControl)) and
    (FShowContainers or not (AComponent is TComponentContainer));
  if Assigned(OnFilter) then OnFilter(Self,AComponent,Result);
end;

function TRFComboBox.TranslateComponent(AComponent: TComponent): TComponent;
begin
  if AComponent is TComponentContainer then Result:=TComponentContainer(AComponent).Component
  else Result:=inherited TranslateComponent(AComponent);
end;

procedure TRFDesigner.SetInspector(const Value: TRFInspector);
var
  OldInspector: TRFInspector;
begin
  if FInspector<>Value then
  begin
    OldInspector:=FInspector;
    FInspector:=Value;
    if Assigned(FInspector) then FInspector.Designer:=Self
    else
      if Assigned(OldInspector) then OldInspector.Designer:=nil;
    if Assigned(FInspector) then FreeNotification(FInspector);
  end;
end;

procedure TRFDesigner.Notification(AComponent: TComponent; Operation: TOperation);
begin
  inherited;
  if not (csDestroying in ComponentState) and (Operation=opRemove) and (AComponent=FInspector) then
    if csDestroying in Inspector.ComponentState then FInspector:=nil
    else Inspector:=nil;
end;

procedure TRFDesigner.DoChange;
begin
  inherited;
  if not SynchroLocked then
    if Assigned(FInspector) then FInspector.Update;
end;

procedure TRFDesigner.DoSelectionChange;
var
  i: Integer;
  C: TControl;
begin
  inherited;
  FLockFusionDesigner:=True;
  try
    if not SynchroLocked then
      if Assigned(FInspector) then
        with FInspector,Self do
        begin
          case ControlCount of
            0: Instance:=DefaultInstance;
            1: Instance:=Component;
          else
            for i:=0 to Pred(ControlCount) do
              if IndexOfInstance(Controls[i])=-1 then AddInstance(Controls[i]);
            if InstanceCount>1 then DeleteInstance(DefaultInstance);
            i:=0;
            while i<InstanceCount do
            begin
              if Instances[i] is TControl then C:=TControl(Instances[i])
              else C:=FindComponentContainer(Instances[i]);
              if ControlIndex(C)=-1 then DeleteInstance(Instances[i])
              else Inc(i);
            end;
          end;
        end;
  finally
    FLockFusionDesigner:=False;
  end;
end;

procedure TRFInspector.SetDesigner(const Value: TRFDesigner);
var
  OldDesigner: TRFDesigner;
begin
  if FDesigner<>Value then
  begin
    OldDesigner:=FDesigner;
    FDesigner:=Value;
    if Assigned(FDesigner) then FDesigner.Inspector:=Self
    else
      if Assigned(OldDesigner) then OldDesigner.Inspector:=nil;
    if not Assigned(FDesigner) then Instance:=FDefaultInstance;
    if Assigned(FDesigner) then FreeNotification(FDesigner);
  end;
end;

procedure TRFInspector.SetDefaultInstance(const Value: TComponent);
begin
  if FDefaultInstance<>Value then
  begin
    FDefaultInstance:=Value;
    if not Assigned(Instance) then Instance:=FDefaultInstance;
    if Assigned(FDefaultInstance) then FreeNotification(FDefaultInstance);
  end;
end;

procedure TRFInspector.Notification(AComponent: TComponent; Operation: TOperation);
begin
  inherited;
  if not (csDestroying in ComponentState) and (Operation=opRemove) then
    if AComponent=FDesigner then
      if csDestroying in Designer.ComponentState then FDesigner:=nil
      else Designer:=nil
    else
      if AComponent=FDefaultInstance then
        FDefaultInstance:=nil;
end;

procedure TRFInspector.Change(TheIndex: Integer);
begin
  inherited;
  if Assigned(FDesigner) then FDesigner.Update;
end;

procedure TRFInspector.Update;
begin
  inherited;
  {$IFNDEF GRFLOCKUPDATEDESIGNER}
  if Assigned(FDesigner) then
    with FDesigner do
      if not FLockFusionDesigner then
      begin
        SynchroLock;
        Lock;
        try
          case InstanceCount of
            0: Control:=nil;
            1:
              if Instance<>Control then
                if Instance is TControl then Control:=TControl(Instance)
                else Component:=Instance;
          end;
        finally
          SynchroUnlock;
          Unlock;
        end;
      end;
  {$ENDIF}
end;

end.
